*************************
Galaxies (`skypy.galaxy`)
*************************

.. automodule:: skypy.galaxy


Luminosities (`skypy.galaxy.luminosity`)
========================================

.. automodule:: skypy.galaxy.luminosity


Ellipticities (`skypy.galaxy.ellipticity`)
==========================================

.. automodule:: skypy.galaxy.ellipticity


Redshifts (`skypy.galaxy.redshift`)
===================================

.. automodule:: skypy.galaxy.redshift


Sizes (`skypy.galaxy.size`)
===========================

.. automodule:: skypy.galaxy.size


Spectra (`skypy.galaxy.spectrum`)
=================================

.. automodule:: skypy.galaxy.spectrum
